==> flink-core-1.0.0-sources.jar: org/apache/flink/api/common/io/compression/GzipInflaterInputStreamFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.flink.api.common.io.compression;

import org.apache.flink.annotation.Internal;

import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import java.util.Collection;
import java.util.zip.GZIPInputStream;

/**
 * Factory for input streams that decompress the GZIP compression format.
 */
@Internal
public class GzipInflaterInputStreamFactory implements InflaterInputStreamFactory<GZIPInputStream> {

	private static GzipInflaterInputStreamFactory INSTANCE = null;

	public static GzipInflaterInputStreamFactory getInstance() {
		if (INSTANCE == null) {
			INSTANCE = new GzipInflaterInputStreamFactory();
		}
		return INSTANCE;
	}
	@Override
	public GZIPInputStream create(InputStream in) throws IOException {
		return new GZIPInputStream(in);
	}

	@Override
	public Collection<String> getCommonFileExtensions() {
		return Arrays.asList("gz", "gzip");
	}
}

==> flink-core-1.7.2-sources.jar: org/apache/flink/api/common/io/compression/GzipInflaterInputStreamFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.io.compression;

import org.apache.flink.annotation.Internal;

import java.io.IOException;
import java.io.InputStream;
import java.util.Arrays;
import java.util.Collection;
import java.util.zip.GZIPInputStream;

/**
 * Factory for input streams that decompress the GZIP compression format.
 */
@Internal
public class GzipInflaterInputStreamFactory implements InflaterInputStreamFactory<GZIPInputStream> {

	private static final GzipInflaterInputStreamFactory INSTANCE = new GzipInflaterInputStreamFactory();

	public static GzipInflaterInputStreamFactory getInstance() {
		return INSTANCE;
	}

	@Override
	public GZIPInputStream create(InputStream in) throws IOException {
		return new GZIPInputStream(in);
	}

	@Override
	public Collection<String> getCommonFileExtensions() {
		return Arrays.asList("gz", "gzip");
	}
}
